/* wptCard.h
 *	Copyright (C) 2003, 2004, 2005 Timo Schulz
 *
 * This file is part of WinPT.
 *
 * WinPT is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * WinPT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WinPT; if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
#ifndef WPT_CARD_H
#define WPT_CARD_H

/* Existing card flags. */
enum card_flag_t {
    GPG_CARDFLAG_NONE    = 0,
    GPG_CARDFLAG_REPLACE = 1,	/* replace existing keys. */
    GPG_CARDFLAG_BAKENC  = 2	/* backup encryption key. */
};

/* Symbolic PIN ids */
enum card_pin_t {
    CARD_ADMIN_PIN,
    CARD_USER_PIN
};

/* (callback) card control ids */
enum card_ctl_t {
    CARD_CTL_INSERT	= '1',	    /* insert card */
    CARD_CTL_REMOVE	= '2',	    /* remove card */
    CARC_CTL_DETECT	= '3',	    /* right card detected */
    CARD_CTL_NO_CARD	= '4' ,	    /* no card found */
    CARD_CTL_NO_READER	= '5'	    /* no reader found */
};


/* openpgp card context. */
struct gpg_card_s {
    char *aid;		/* appID */
    char *card_type;
    char *version;	/* version */
    char *vendor;	/* vendor */
    char *serial;	/* serial number */
    char *surname;	/* card users surname */
    char *givenname;	/* card users given name */
    char *lang;		/* language */
    char sex;		/* card users sex */
    char *url;		/* key url */
    char *login;	/* login data (name) */
    int force_pin;
    char *maxpinlen[3];
    int sig_count;	/* signature counter */
    char *ca_fpr[3];	/* CA fingerprints */    
    char *fpr[3];	/* key fingerprints */
    long fpr_created[3];/* fingerprint timestamps. */
    char *fpr_created_str[3];
};
typedef struct gpg_card_s *gpg_card_t;

/* PIN callback context. */
struct pin_cb_ctx_s {
    int which;		/* which command to execute. */
    char *info_text;	/* additional info text. */
    char *apin;		/* admin pin */
    char *upin;		/* user pin */
};

/* Card callback context. */
struct card_cb_s {
    int cancel;		    /* 1=user cancelled operation. */
    int init;
    int code;		    /* 1=user need to insert card. */
    char val[128];	    /* application specific value. */
};


/*-- wptCardManager.cpp --*/
const char* card_callback (int code, void *opaque);

#endif /*WPT_CARD_H*/
